==> mingw-w64-starpu-1.4.5-2.src.tar.zst: starpu-1.4.5/doc/doxygen_web_faq/html_web_faq/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU FAQs", "index.html", [
    [ "Check List When Performance Are Not There", "CheckListWhenPerformanceAreNotThere.html", [
      [ "Check Task Size", "CheckListWhenPerformanceAreNotThere.html#CheckTaskSize", null ],
      [ "Configuration Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#ConfigurationImprovePerformance", null ],
      [ "Data Related Features Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#DataRelatedFeaturesToImprovePerformance", null ],
      [ "Task Related Features Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#TaskRelatedFeaturesToImprovePerformance", null ],
      [ "Scheduling Related Features Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#SchedulingRelatedFeaturesToImprovePerformance", null ],
      [ "CUDA-specific Optimizations", "CheckListWhenPerformanceAreNotThere.html#CUDA-specificOptimizations", null ],
      [ "OpenCL-specific Optimizations", "CheckListWhenPerformanceAreNotThere.html#OpenCL-specificOptimizations", null ],
      [ "Detecting Stuck Conditions", "CheckListWhenPerformanceAreNotThere.html#DetectionStuckConditions", null ],
      [ "How to Limit Memory Used By StarPU And Cache Buffer Allocations", "CheckListWhenPerformanceAreNotThere.html#HowToLimitMemoryPerNode", null ],
      [ "How To Reduce The Memory Footprint Of Internal Data Structures", "CheckListWhenPerformanceAreNotThere.html#HowToReduceTheMemoryFootprintOfInternalDataStructures", null ],
      [ "How To Reuse Memory", "CheckListWhenPerformanceAreNotThere.html#HowtoReuseMemory", null ],
      [ "Performance Model Calibration", "CheckListWhenPerformanceAreNotThere.html#PerformanceModelCalibration", null ],
      [ "Profiling", "CheckListWhenPerformanceAreNotThere.html#Profiling", null ],
      [ "Overhead Profiling", "CheckListWhenPerformanceAreNotThere.html#OverheadProfiling", null ]
    ] ],
    [ "Frequently Asked Questions", "FrequentlyAskedQuestions.html", [
      [ "How To Initialize A Computation Library Once For Each Worker?", "FrequentlyAskedQuestions.html#HowToInitializeAComputationLibraryOnceForEachWorker", null ],
      [ "Hardware Topology", "FrequentlyAskedQuestions.html#HardwareTopology", [
        [ "Interoperability hwloc", "FrequentlyAskedQuestions.html#InteroperabilityHWLOC", null ],
        [ "Memory", "FrequentlyAskedQuestions.html#TopologyMemory", null ],
        [ "Workers", "FrequentlyAskedQuestions.html#TopologyWorkers", null ],
        [ "Bus", "FrequentlyAskedQuestions.html#TopologyBus", null ]
      ] ],
      [ "Using The Driver API", "FrequentlyAskedQuestions.html#UsingTheDriverAPI", null ],
      [ "On-GPU Rendering", "FrequentlyAskedQuestions.html#On-GPURendering", null ],
      [ "Using StarPU With MKL 11 (Intel Composer XE 2013)", "FrequentlyAskedQuestions.html#UsingStarPUWithMKL", null ],
      [ "Thread Binding on NetBSD", "FrequentlyAskedQuestions.html#ThreadBindingOnNetBSD", null ],
      [ "StarPU permanently eats 100% of all CPUs", "FrequentlyAskedQuestions.html#StarPUEatsCPUs", null ],
      [ "Interleaving StarPU and non-StarPU code", "FrequentlyAskedQuestions.html#PauseResume", null ],
      [ "When running with CUDA or OpenCL devices, I am seeing less CPU cores", "FrequentlyAskedQuestions.html#GPUEatingCores", null ],
      [ "StarPU does not see my CUDA device", "FrequentlyAskedQuestions.html#CUDADrivers", null ],
      [ "StarPU does not see my OpenCL device", "FrequentlyAskedQuestions.html#OpenCLDrivers", null ],
      [ "There seems to be errors when copying to and from CUDA devices", "FrequentlyAskedQuestions.html#CUDACopyError", null ],
      [ "I keep getting a \"Incorrect performance model file\" error", "FrequentlyAskedQuestions.html#IncorrectPerformanceModelFile", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"CheckListWhenPerformanceAreNotThere.html",
"group__API__Codelet__And__Tasks.html#adac9af88fed23241fc65259712352126",
"group__API__Data__Interfaces.html#ae1d888af673475dbcf85104b6c359a6e",
"group__API__Data__Interfaces.html#structstarpu__variable__interface",
"group__API__HIP__Extensions.html#gadc796fee8ebed3e8f4c12fb242f4c857",
"group__API__MPI__Support.html#ga25408759187b030c633314855589ebcd",
"group__API__OpenCL__Extensions.html#ga03f34ac98495afc5d0f268e366f80598",
"group__API__Perf__Monitoring.html#ga36c44ab10f14200d43704d8771246997",
"group__API__Running__Drivers.html#ga497d48a24107dfebf6ef3ad40d4a6df8",
"group__API__Scheduling__Policy.html#gaa01a5b65a4c387da5f7ca711c03d41c8",
"group__API__Workers.html#gac043c52077692456604a2f2f161b86ba",
"interfacefstarpu__mod_1_1fstarpu__data__set__reduction__methods.html",
"interfacefstarpu__mod_1_1fstarpu__tag__wait__array.html",
"sc__hypervisor__monitoring_8h.html#a0cd92328373b9b5427e6bb48a44d8644"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.8-1.src.tar.zst: starpu-1.4.8/doc/doxygen_web_faq/html_web_faq/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU FAQs", "index.html", [
    [ "Check List When Performance Are Not There", "CheckListWhenPerformanceAreNotThere.html", [
      [ "Check Task Size", "CheckListWhenPerformanceAreNotThere.html#CheckTaskSize", null ],
      [ "Configuration Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#ConfigurationImprovePerformance", null ],
      [ "Data Related Features Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#DataRelatedFeaturesToImprovePerformance", null ],
      [ "Task Related Features Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#TaskRelatedFeaturesToImprovePerformance", null ],
      [ "Scheduling Related Features Which May Improve Performance", "CheckListWhenPerformanceAreNotThere.html#SchedulingRelatedFeaturesToImprovePerformance", null ],
      [ "CUDA-specific Optimizations", "CheckListWhenPerformanceAreNotThere.html#CUDA-specificOptimizations", null ],
      [ "OpenCL-specific Optimizations", "CheckListWhenPerformanceAreNotThere.html#OpenCL-specificOptimizations", null ],
      [ "Detecting Stuck Conditions", "CheckListWhenPerformanceAreNotThere.html#DetectionStuckConditions", null ],
      [ "How to Limit Memory Used By StarPU And Cache Buffer Allocations", "CheckListWhenPerformanceAreNotThere.html#HowToLimitMemoryPerNode", null ],
      [ "How To Reduce The Memory Footprint Of Internal Data Structures", "CheckListWhenPerformanceAreNotThere.html#HowToReduceTheMemoryFootprintOfInternalDataStructures", null ],
      [ "How To Reuse Memory", "CheckListWhenPerformanceAreNotThere.html#HowtoReuseMemory", null ],
      [ "Performance Model Calibration", "CheckListWhenPerformanceAreNotThere.html#PerformanceModelCalibration", null ],
      [ "Profiling", "CheckListWhenPerformanceAreNotThere.html#Profiling", null ],
      [ "Overhead Profiling", "CheckListWhenPerformanceAreNotThere.html#OverheadProfiling", null ]
    ] ],
    [ "Frequently Asked Questions", "FrequentlyAskedQuestions.html", [
      [ "How To Initialize A Computation Library Once For Each Worker?", "FrequentlyAskedQuestions.html#HowToInitializeAComputationLibraryOnceForEachWorker", null ],
      [ "Hardware Topology", "FrequentlyAskedQuestions.html#HardwareTopology", [
        [ "Interoperability hwloc", "FrequentlyAskedQuestions.html#InteroperabilityHWLOC", null ],
        [ "Memory", "FrequentlyAskedQuestions.html#TopologyMemory", null ],
        [ "Workers", "FrequentlyAskedQuestions.html#TopologyWorkers", null ],
        [ "Bus", "FrequentlyAskedQuestions.html#TopologyBus", null ]
      ] ],
      [ "Using The Driver API", "FrequentlyAskedQuestions.html#UsingTheDriverAPI", null ],
      [ "On-GPU Rendering", "FrequentlyAskedQuestions.html#On-GPURendering", null ],
      [ "Using StarPU With MKL 11 (Intel Composer XE 2013)", "FrequentlyAskedQuestions.html#UsingStarPUWithMKL", null ],
      [ "Thread Binding on NetBSD", "FrequentlyAskedQuestions.html#ThreadBindingOnNetBSD", null ],
      [ "StarPU permanently eats 100% of all CPUs", "FrequentlyAskedQuestions.html#StarPUEatsCPUs", null ],
      [ "Interleaving StarPU and non-StarPU code", "FrequentlyAskedQuestions.html#PauseResume", null ],
      [ "When running with CUDA or OpenCL devices, I am seeing less CPU cores", "FrequentlyAskedQuestions.html#GPUEatingCores", null ],
      [ "StarPU does not see my CUDA device", "FrequentlyAskedQuestions.html#CUDADrivers", null ],
      [ "StarPU does not see my HIP device", "FrequentlyAskedQuestions.html#HIPDrivers", null ],
      [ "StarPU does not see my OpenCL device", "FrequentlyAskedQuestions.html#OpenCLDrivers", null ],
      [ "There seems to be errors when copying to and from CUDA devices", "FrequentlyAskedQuestions.html#CUDACopyError", null ],
      [ "I keep getting a \"Incorrect performance model file\" error", "FrequentlyAskedQuestions.html#IncorrectPerformanceModelFile", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"CheckListWhenPerformanceAreNotThere.html",
"group__API__Codelet__And__Tasks.html#ad5f00ed5a0a59b72c0d90d9718376893",
"group__API__Data__Interfaces.html#ae002548f6392819ff90d72f64898dca6",
"group__API__Data__Interfaces.html#structstarpu__multiformat__interface",
"group__API__HIP__Extensions.html#ga895d3031a83129e4c874eadedcfb1912",
"group__API__MPI__Support.html#ga1998499da59f8849a7ee5de16b0f5bab",
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__perfmodel__select__data",
"group__API__Perf__Monitoring.html#ga0a9c21a6b765059a5f5f72ab10dd99fa",
"group__API__Profiling__Tool.html#structstarpu__prof__tool__info",
"group__API__Scheduling__Policy.html#ga87e2aacf5892951d5333a3421e90f278",
"group__API__Workers.html#gaa6e5fd90ba1b431ed025006d190fb421",
"interfacefstarpu__mod_1_1fstarpu__data__register__same.html",
"interfacefstarpu__mod_1_1fstarpu__tag__notify__from__apps.html",
"sc__hypervisor__config_8h.html#afdb68c657fb202f52938f5268749003d"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
